# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/ranker/events.proto',
  package='eolymp.ranker',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/ranker;ranker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/ranker/events.proto\x12\reolymp.ranker\"V\n\x16RebuildScoreboardEvent\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x03 \x01(\tB5Z3github.com/eolymp/contracts/go/eolymp/ranker;rankerb\x06proto3'
)




_REBUILDSCOREBOARDEVENT = _descriptor.Descriptor(
  name='RebuildScoreboardEvent',
  full_name='eolymp.ranker.RebuildScoreboardEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.ranker.RebuildScoreboardEvent.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.RebuildScoreboardEvent.scoreboard_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activity_id', full_name='eolymp.ranker.RebuildScoreboardEvent.activity_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=131,
)

DESCRIPTOR.message_types_by_name['RebuildScoreboardEvent'] = _REBUILDSCOREBOARDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RebuildScoreboardEvent = _reflection.GeneratedProtocolMessageType('RebuildScoreboardEvent', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDEVENT,
  '__module__' : 'eolymp.ranker.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.RebuildScoreboardEvent)
  })
_sym_db.RegisterMessage(RebuildScoreboardEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
