# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.helpdesk import document_pb2 as eolymp_dot_helpdesk_dot_document__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/helpdesk/events.proto',
  package='eolymp.helpdesk',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/helpdesk;helpdesk',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65olymp/helpdesk/events.proto\x12\x0f\x65olymp.helpdesk\x1a\x1e\x65olymp/helpdesk/document.proto\"C\n\x14\x44ocumentCreatedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"C\n\x14\x44ocumentUpdatedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"C\n\x14\x44ocumentDeletedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.DocumentB9Z7github.com/eolymp/contracts/go/eolymp/helpdesk;helpdeskb\x06proto3'
  ,
  dependencies=[eolymp_dot_helpdesk_dot_document__pb2.DESCRIPTOR,])




_DOCUMENTCREATEDEVENT = _descriptor.Descriptor(
  name='DocumentCreatedEvent',
  full_name='eolymp.helpdesk.DocumentCreatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.DocumentCreatedEvent.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=148,
)


_DOCUMENTUPDATEDEVENT = _descriptor.Descriptor(
  name='DocumentUpdatedEvent',
  full_name='eolymp.helpdesk.DocumentUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.DocumentUpdatedEvent.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=217,
)


_DOCUMENTDELETEDEVENT = _descriptor.Descriptor(
  name='DocumentDeletedEvent',
  full_name='eolymp.helpdesk.DocumentDeletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.DocumentDeletedEvent.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=286,
)

_DOCUMENTCREATEDEVENT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_DOCUMENTUPDATEDEVENT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_DOCUMENTDELETEDEVENT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
DESCRIPTOR.message_types_by_name['DocumentCreatedEvent'] = _DOCUMENTCREATEDEVENT
DESCRIPTOR.message_types_by_name['DocumentUpdatedEvent'] = _DOCUMENTUPDATEDEVENT
DESCRIPTOR.message_types_by_name['DocumentDeletedEvent'] = _DOCUMENTDELETEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DocumentCreatedEvent = _reflection.GeneratedProtocolMessageType('DocumentCreatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTCREATEDEVENT,
  '__module__' : 'eolymp.helpdesk.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DocumentCreatedEvent)
  })
_sym_db.RegisterMessage(DocumentCreatedEvent)

DocumentUpdatedEvent = _reflection.GeneratedProtocolMessageType('DocumentUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTUPDATEDEVENT,
  '__module__' : 'eolymp.helpdesk.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DocumentUpdatedEvent)
  })
_sym_db.RegisterMessage(DocumentUpdatedEvent)

DocumentDeletedEvent = _reflection.GeneratedProtocolMessageType('DocumentDeletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTDELETEDEVENT,
  '__module__' : 'eolymp.helpdesk.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DocumentDeletedEvent)
  })
_sym_db.RegisterMessage(DocumentDeletedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
