# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/community.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/community/community.proto',
  package='eolymp.community',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/community;community',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/community/community.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a eolymp/community/attribute.proto\x1a\x1d\x65olymp/community/member.proto\"N\n\x0eJoinSpaceInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06values\x18\x14 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"$\n\x0fJoinSpaceOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"E\n\x13RegisterMemberInput\x12.\n\x06values\x18\x01 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"\x16\n\x14RegisterMemberOutput\"\x11\n\x0fLeaveSpaceInput\"\x12\n\x10LeaveSpaceOutput\":\n\x0e\x41\x64\x64MemberInput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"$\n\x0f\x41\x64\x64MemberOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"P\n\x11UpdateMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12(\n\x06member\x18\x02 \x01(\x0b\x32\x18.eolymp.community.Member\"\x14\n\x12UpdateMemberOutput\"&\n\x11RemoveMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x14\n\x12RemoveMemberOutput\"(\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"@\n\x14\x44\x65scribeMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\x17\n\x15IntrospectMemberInput\"B\n\x16IntrospectMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\xba\x02\n\x10ListMembersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.community.ListMembersInput.Filter\x1a\xcb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\x08\x64isabled\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"K\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.community.Member\"Z\n\x11\x41\x64\x64\x41ttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x14\n\x12\x41\x64\x64\x41ttributeOutput\"]\n\x14UpdateAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x17\n\x15UpdateAttributeOutput\"-\n\x14RemoveAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"\x17\n\x15RemoveAttributeOutput\"/\n\x16\x44\x65scribeAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"I\n\x17\x44\x65scribeAttributeOutput\x12.\n\tattribute\x18\x01 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\xee\x02\n\x13ListAttributesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.community.ListAttributesInput.Filter\x1a\xf9\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03key\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06hidden\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08required\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x14ListAttributesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.community.Attribute2\xb9\x13\n\tCommunity\x12\x98\x01\n\tJoinSpace\x12 .eolymp.community.JoinSpaceInput\x1a!.eolymp.community.JoinSpaceOutput\"F\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x14\x1a\x0f/community/selfb\x01*\x12\x9b\x01\n\nLeaveSpace\x12!.eolymp.community.LeaveSpaceInput\x1a\".eolymp.community.LeaveSpaceOutput\"F\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x14*\x0f/community/selfb\x01*\x12\xa8\x01\n\x0eRegisterMember\x12%.eolymp.community.RegisterMemberInput\x1a&.eolymp.community.RegisterMemberOutput\"G\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x14\"\x0f/community/selfb\x01*\x12\xb2\x01\n\x10IntrospectMember\x12\'.eolymp.community.IntrospectMemberInput\x1a(.eolymp.community.IntrospectMemberOutput\"K\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x19\x12\x0f/community/selfb\x06member\x12\x9c\x01\n\tAddMember\x12 .eolymp.community.AddMemberInput\x1a!.eolymp.community.AddMemberOutput\"J\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17\"\x12/community/membersb\x01*\x12\xb1\x01\n\x0cUpdateMember\x12#.eolymp.community.UpdateMemberInput\x1a$.eolymp.community.UpdateMemberOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02#\x1a\x1e/community/members/{member_id}b\x01*\x12\xb1\x01\n\x0cRemoveMember\x12#.eolymp.community.RemoveMemberInput\x1a$.eolymp.community.RemoveMemberOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02#*\x1e/community/members/{member_id}b\x01*\x12\xbb\x01\n\x0e\x44\x65scribeMember\x12%.eolymp.community.DescribeMemberInput\x1a&.eolymp.community.DescribeMemberOutput\"Z\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02(\x12\x1e/community/members/{member_id}b\x06member\x12\xa1\x01\n\x0bListMembers\x12\".eolymp.community.ListMembersInput\x1a#.eolymp.community.ListMembersOutput\"I\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17\x12\x12/community/membersb\x01*\x12\xa8\x01\n\x0c\x41\x64\x64\x41ttribute\x12#.eolymp.community.AddAttributeInput\x1a$.eolymp.community.AddAttributeOutput\"M\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1a\"\x15/community/attributesb\x01*\x12\xc1\x01\n\x0fUpdateAttribute\x12&.eolymp.community.UpdateAttributeInput\x1a\'.eolymp.community.UpdateAttributeOutput\"]\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\x1a%/community/attributes/{attribute_key}b\x01*\x12\xc1\x01\n\x0fRemoveAttribute\x12&.eolymp.community.RemoveAttributeInput\x1a\'.eolymp.community.RemoveAttributeOutput\"]\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02**%/community/attributes/{attribute_key}b\x01*\x12\xc6\x01\n\x11\x44\x65scribeAttribute\x12(.eolymp.community.DescribeAttributeInput\x1a).eolymp.community.DescribeAttributeOutput\"\\\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\x12%/community/attributes/{attribute_key}b\x01*\x12\xad\x01\n\x0eListAttributes\x12%.eolymp.community.ListAttributesInput\x1a&.eolymp.community.ListAttributesOutput\"L\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1a\x12\x15/community/attributesb\x01*B;Z9github.com/eolymp/contracts/go/eolymp/community;communityb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_community_dot_attribute__pb2.DESCRIPTOR,eolymp_dot_community_dot_member__pb2.DESCRIPTOR,])




_JOINSPACEINPUT = _descriptor.Descriptor(
  name='JoinSpaceInput',
  full_name='eolymp.community.JoinSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.community.JoinSpaceInput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='eolymp.community.JoinSpaceInput.values', index=1,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=331,
)


_JOINSPACEOUTPUT = _descriptor.Descriptor(
  name='JoinSpaceOutput',
  full_name='eolymp.community.JoinSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.JoinSpaceOutput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=369,
)


_REGISTERMEMBERINPUT = _descriptor.Descriptor(
  name='RegisterMemberInput',
  full_name='eolymp.community.RegisterMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='eolymp.community.RegisterMemberInput.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=440,
)


_REGISTERMEMBEROUTPUT = _descriptor.Descriptor(
  name='RegisterMemberOutput',
  full_name='eolymp.community.RegisterMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=464,
)


_LEAVESPACEINPUT = _descriptor.Descriptor(
  name='LeaveSpaceInput',
  full_name='eolymp.community.LeaveSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=483,
)


_LEAVESPACEOUTPUT = _descriptor.Descriptor(
  name='LeaveSpaceOutput',
  full_name='eolymp.community.LeaveSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=503,
)


_ADDMEMBERINPUT = _descriptor.Descriptor(
  name='AddMemberInput',
  full_name='eolymp.community.AddMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.AddMemberInput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=563,
)


_ADDMEMBEROUTPUT = _descriptor.Descriptor(
  name='AddMemberOutput',
  full_name='eolymp.community.AddMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.AddMemberOutput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=601,
)


_UPDATEMEMBERINPUT = _descriptor.Descriptor(
  name='UpdateMemberInput',
  full_name='eolymp.community.UpdateMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.UpdateMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.UpdateMemberInput.member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=683,
)


_UPDATEMEMBEROUTPUT = _descriptor.Descriptor(
  name='UpdateMemberOutput',
  full_name='eolymp.community.UpdateMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=705,
)


_REMOVEMEMBERINPUT = _descriptor.Descriptor(
  name='RemoveMemberInput',
  full_name='eolymp.community.RemoveMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.RemoveMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=707,
  serialized_end=745,
)


_REMOVEMEMBEROUTPUT = _descriptor.Descriptor(
  name='RemoveMemberOutput',
  full_name='eolymp.community.RemoveMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=767,
)


_DESCRIBEMEMBERINPUT = _descriptor.Descriptor(
  name='DescribeMemberInput',
  full_name='eolymp.community.DescribeMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.DescribeMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=809,
)


_DESCRIBEMEMBEROUTPUT = _descriptor.Descriptor(
  name='DescribeMemberOutput',
  full_name='eolymp.community.DescribeMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.DescribeMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=875,
)


_INTROSPECTMEMBERINPUT = _descriptor.Descriptor(
  name='IntrospectMemberInput',
  full_name='eolymp.community.IntrospectMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=900,
)


_INTROSPECTMEMBEROUTPUT = _descriptor.Descriptor(
  name='IntrospectMemberOutput',
  full_name='eolymp.community.IntrospectMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.IntrospectMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=968,
)


_LISTMEMBERSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.community.ListMembersInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.community.ListMembersInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.community.ListMembersInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='eolymp.community.ListMembersInput.Filter.disabled', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.community.ListMembersInput.Filter.name', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1285,
)

_LISTMEMBERSINPUT = _descriptor.Descriptor(
  name='ListMembersInput',
  full_name='eolymp.community.ListMembersInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.community.ListMembersInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.community.ListMembersInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.community.ListMembersInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMEMBERSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1285,
)


_LISTMEMBERSOUTPUT = _descriptor.Descriptor(
  name='ListMembersOutput',
  full_name='eolymp.community.ListMembersOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.community.ListMembersOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.community.ListMembersOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1287,
  serialized_end=1362,
)


_ADDATTRIBUTEINPUT = _descriptor.Descriptor(
  name='AddAttributeInput',
  full_name='eolymp.community.AddAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.AddAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='eolymp.community.AddAttributeInput.attribute', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1364,
  serialized_end=1454,
)


_ADDATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='AddAttributeOutput',
  full_name='eolymp.community.AddAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1476,
)


_UPDATEATTRIBUTEINPUT = _descriptor.Descriptor(
  name='UpdateAttributeInput',
  full_name='eolymp.community.UpdateAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.UpdateAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='eolymp.community.UpdateAttributeInput.attribute', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1478,
  serialized_end=1571,
)


_UPDATEATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='UpdateAttributeOutput',
  full_name='eolymp.community.UpdateAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1573,
  serialized_end=1596,
)


_REMOVEATTRIBUTEINPUT = _descriptor.Descriptor(
  name='RemoveAttributeInput',
  full_name='eolymp.community.RemoveAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.RemoveAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1598,
  serialized_end=1643,
)


_REMOVEATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='RemoveAttributeOutput',
  full_name='eolymp.community.RemoveAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1668,
)


_DESCRIBEATTRIBUTEINPUT = _descriptor.Descriptor(
  name='DescribeAttributeInput',
  full_name='eolymp.community.DescribeAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.DescribeAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1670,
  serialized_end=1717,
)


_DESCRIBEATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='DescribeAttributeOutput',
  full_name='eolymp.community.DescribeAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='eolymp.community.DescribeAttributeOutput.attribute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1792,
)


_LISTATTRIBUTESINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.community.ListAttributesInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.community.ListAttributesInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.community.ListAttributesInput.Filter.key', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='eolymp.community.ListAttributesInput.Filter.hidden', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='eolymp.community.ListAttributesInput.Filter.required', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.community.ListAttributesInput.Filter.type', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1912,
  serialized_end=2161,
)

_LISTATTRIBUTESINPUT = _descriptor.Descriptor(
  name='ListAttributesInput',
  full_name='eolymp.community.ListAttributesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.community.ListAttributesInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.community.ListAttributesInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.community.ListAttributesInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTATTRIBUTESINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1795,
  serialized_end=2161,
)


_LISTATTRIBUTESOUTPUT = _descriptor.Descriptor(
  name='ListAttributesOutput',
  full_name='eolymp.community.ListAttributesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.community.ListAttributesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.community.ListAttributesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2244,
)

_JOINSPACEINPUT.fields_by_name['values'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER_VALUE
_REGISTERMEMBERINPUT.fields_by_name['values'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER_VALUE
_ADDMEMBERINPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_UPDATEMEMBERINPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_DESCRIBEMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_INTROSPECTMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_LISTMEMBERSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['disabled'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTMEMBERSINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTMEMBERSINPUT_FILTER.containing_type = _LISTMEMBERSINPUT
_LISTMEMBERSINPUT.fields_by_name['filters'].message_type = _LISTMEMBERSINPUT_FILTER
_LISTMEMBERSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_ADDATTRIBUTEINPUT.fields_by_name['attribute'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
_UPDATEATTRIBUTEINPUT.fields_by_name['attribute'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
_DESCRIBEATTRIBUTEOUTPUT.fields_by_name['attribute'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['key'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['hidden'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['required'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['type'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTATTRIBUTESINPUT_FILTER.containing_type = _LISTATTRIBUTESINPUT
_LISTATTRIBUTESINPUT.fields_by_name['filters'].message_type = _LISTATTRIBUTESINPUT_FILTER
_LISTATTRIBUTESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
DESCRIPTOR.message_types_by_name['JoinSpaceInput'] = _JOINSPACEINPUT
DESCRIPTOR.message_types_by_name['JoinSpaceOutput'] = _JOINSPACEOUTPUT
DESCRIPTOR.message_types_by_name['RegisterMemberInput'] = _REGISTERMEMBERINPUT
DESCRIPTOR.message_types_by_name['RegisterMemberOutput'] = _REGISTERMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['LeaveSpaceInput'] = _LEAVESPACEINPUT
DESCRIPTOR.message_types_by_name['LeaveSpaceOutput'] = _LEAVESPACEOUTPUT
DESCRIPTOR.message_types_by_name['AddMemberInput'] = _ADDMEMBERINPUT
DESCRIPTOR.message_types_by_name['AddMemberOutput'] = _ADDMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['UpdateMemberInput'] = _UPDATEMEMBERINPUT
DESCRIPTOR.message_types_by_name['UpdateMemberOutput'] = _UPDATEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['RemoveMemberInput'] = _REMOVEMEMBERINPUT
DESCRIPTOR.message_types_by_name['RemoveMemberOutput'] = _REMOVEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['DescribeMemberInput'] = _DESCRIBEMEMBERINPUT
DESCRIPTOR.message_types_by_name['DescribeMemberOutput'] = _DESCRIBEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberInput'] = _INTROSPECTMEMBERINPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberOutput'] = _INTROSPECTMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['ListMembersInput'] = _LISTMEMBERSINPUT
DESCRIPTOR.message_types_by_name['ListMembersOutput'] = _LISTMEMBERSOUTPUT
DESCRIPTOR.message_types_by_name['AddAttributeInput'] = _ADDATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['AddAttributeOutput'] = _ADDATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['UpdateAttributeInput'] = _UPDATEATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['UpdateAttributeOutput'] = _UPDATEATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['RemoveAttributeInput'] = _REMOVEATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['RemoveAttributeOutput'] = _REMOVEATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeAttributeInput'] = _DESCRIBEATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['DescribeAttributeOutput'] = _DESCRIBEATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['ListAttributesInput'] = _LISTATTRIBUTESINPUT
DESCRIPTOR.message_types_by_name['ListAttributesOutput'] = _LISTATTRIBUTESOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JoinSpaceInput = _reflection.GeneratedProtocolMessageType('JoinSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _JOINSPACEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.JoinSpaceInput)
  })
_sym_db.RegisterMessage(JoinSpaceInput)

JoinSpaceOutput = _reflection.GeneratedProtocolMessageType('JoinSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _JOINSPACEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.JoinSpaceOutput)
  })
_sym_db.RegisterMessage(JoinSpaceOutput)

RegisterMemberInput = _reflection.GeneratedProtocolMessageType('RegisterMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RegisterMemberInput)
  })
_sym_db.RegisterMessage(RegisterMemberInput)

RegisterMemberOutput = _reflection.GeneratedProtocolMessageType('RegisterMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RegisterMemberOutput)
  })
_sym_db.RegisterMessage(RegisterMemberOutput)

LeaveSpaceInput = _reflection.GeneratedProtocolMessageType('LeaveSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _LEAVESPACEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.LeaveSpaceInput)
  })
_sym_db.RegisterMessage(LeaveSpaceInput)

LeaveSpaceOutput = _reflection.GeneratedProtocolMessageType('LeaveSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _LEAVESPACEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.LeaveSpaceOutput)
  })
_sym_db.RegisterMessage(LeaveSpaceOutput)

AddMemberInput = _reflection.GeneratedProtocolMessageType('AddMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddMemberInput)
  })
_sym_db.RegisterMessage(AddMemberInput)

AddMemberOutput = _reflection.GeneratedProtocolMessageType('AddMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddMemberOutput)
  })
_sym_db.RegisterMessage(AddMemberOutput)

UpdateMemberInput = _reflection.GeneratedProtocolMessageType('UpdateMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateMemberInput)
  })
_sym_db.RegisterMessage(UpdateMemberInput)

UpdateMemberOutput = _reflection.GeneratedProtocolMessageType('UpdateMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateMemberOutput)
  })
_sym_db.RegisterMessage(UpdateMemberOutput)

RemoveMemberInput = _reflection.GeneratedProtocolMessageType('RemoveMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveMemberInput)
  })
_sym_db.RegisterMessage(RemoveMemberInput)

RemoveMemberOutput = _reflection.GeneratedProtocolMessageType('RemoveMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveMemberOutput)
  })
_sym_db.RegisterMessage(RemoveMemberOutput)

DescribeMemberInput = _reflection.GeneratedProtocolMessageType('DescribeMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeMemberInput)
  })
_sym_db.RegisterMessage(DescribeMemberInput)

DescribeMemberOutput = _reflection.GeneratedProtocolMessageType('DescribeMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeMemberOutput)
  })
_sym_db.RegisterMessage(DescribeMemberOutput)

IntrospectMemberInput = _reflection.GeneratedProtocolMessageType('IntrospectMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.IntrospectMemberInput)
  })
_sym_db.RegisterMessage(IntrospectMemberInput)

IntrospectMemberOutput = _reflection.GeneratedProtocolMessageType('IntrospectMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.IntrospectMemberOutput)
  })
_sym_db.RegisterMessage(IntrospectMemberOutput)

ListMembersInput = _reflection.GeneratedProtocolMessageType('ListMembersInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTMEMBERSINPUT_FILTER,
    '__module__' : 'eolymp.community.community_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.community.ListMembersInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTMEMBERSINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListMembersInput)
  })
_sym_db.RegisterMessage(ListMembersInput)
_sym_db.RegisterMessage(ListMembersInput.Filter)

ListMembersOutput = _reflection.GeneratedProtocolMessageType('ListMembersOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListMembersOutput)
  })
_sym_db.RegisterMessage(ListMembersOutput)

AddAttributeInput = _reflection.GeneratedProtocolMessageType('AddAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddAttributeInput)
  })
_sym_db.RegisterMessage(AddAttributeInput)

AddAttributeOutput = _reflection.GeneratedProtocolMessageType('AddAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddAttributeOutput)
  })
_sym_db.RegisterMessage(AddAttributeOutput)

UpdateAttributeInput = _reflection.GeneratedProtocolMessageType('UpdateAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateAttributeInput)
  })
_sym_db.RegisterMessage(UpdateAttributeInput)

UpdateAttributeOutput = _reflection.GeneratedProtocolMessageType('UpdateAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateAttributeOutput)
  })
_sym_db.RegisterMessage(UpdateAttributeOutput)

RemoveAttributeInput = _reflection.GeneratedProtocolMessageType('RemoveAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveAttributeInput)
  })
_sym_db.RegisterMessage(RemoveAttributeInput)

RemoveAttributeOutput = _reflection.GeneratedProtocolMessageType('RemoveAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveAttributeOutput)
  })
_sym_db.RegisterMessage(RemoveAttributeOutput)

DescribeAttributeInput = _reflection.GeneratedProtocolMessageType('DescribeAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeAttributeInput)
  })
_sym_db.RegisterMessage(DescribeAttributeInput)

DescribeAttributeOutput = _reflection.GeneratedProtocolMessageType('DescribeAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeAttributeOutput)
  })
_sym_db.RegisterMessage(DescribeAttributeOutput)

ListAttributesInput = _reflection.GeneratedProtocolMessageType('ListAttributesInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTATTRIBUTESINPUT_FILTER,
    '__module__' : 'eolymp.community.community_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.community.ListAttributesInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTATTRIBUTESINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListAttributesInput)
  })
_sym_db.RegisterMessage(ListAttributesInput)
_sym_db.RegisterMessage(ListAttributesInput.Filter)

ListAttributesOutput = _reflection.GeneratedProtocolMessageType('ListAttributesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTRIBUTESOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListAttributesOutput)
  })
_sym_db.RegisterMessage(ListAttributesOutput)


DESCRIPTOR._options = None

_COMMUNITY = _descriptor.ServiceDescriptor(
  name='Community',
  full_name='eolymp.community.Community',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2247,
  serialized_end=4736,
  methods=[
  _descriptor.MethodDescriptor(
    name='JoinSpace',
    full_name='eolymp.community.Community.JoinSpace',
    index=0,
    containing_service=None,
    input_type=_JOINSPACEINPUT,
    output_type=_JOINSPACEOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\024\032\017/community/selfb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveSpace',
    full_name='eolymp.community.Community.LeaveSpace',
    index=1,
    containing_service=None,
    input_type=_LEAVESPACEINPUT,
    output_type=_LEAVESPACEOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\024*\017/community/selfb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterMember',
    full_name='eolymp.community.Community.RegisterMember',
    index=2,
    containing_service=None,
    input_type=_REGISTERMEMBERINPUT,
    output_type=_REGISTERMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\024\"\017/community/selfb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectMember',
    full_name='eolymp.community.Community.IntrospectMember',
    index=3,
    containing_service=None,
    input_type=_INTROSPECTMEMBERINPUT,
    output_type=_INTROSPECTMEMBEROUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\031\022\017/community/selfb\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddMember',
    full_name='eolymp.community.Community.AddMember',
    index=4,
    containing_service=None,
    input_type=_ADDMEMBERINPUT,
    output_type=_ADDMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\027\"\022/community/membersb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMember',
    full_name='eolymp.community.Community.UpdateMember',
    index=5,
    containing_service=None,
    input_type=_UPDATEMEMBERINPUT,
    output_type=_UPDATEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002#\032\036/community/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveMember',
    full_name='eolymp.community.Community.RemoveMember',
    index=6,
    containing_service=None,
    input_type=_REMOVEMEMBERINPUT,
    output_type=_REMOVEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002#*\036/community/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeMember',
    full_name='eolymp.community.Community.DescribeMember',
    index=7,
    containing_service=None,
    input_type=_DESCRIBEMEMBERINPUT,
    output_type=_DESCRIBEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002(\022\036/community/members/{member_id}b\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='eolymp.community.Community.ListMembers',
    index=8,
    containing_service=None,
    input_type=_LISTMEMBERSINPUT,
    output_type=_LISTMEMBERSOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\027\022\022/community/membersb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddAttribute',
    full_name='eolymp.community.Community.AddAttribute',
    index=9,
    containing_service=None,
    input_type=_ADDATTRIBUTEINPUT,
    output_type=_ADDATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\032\"\025/community/attributesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAttribute',
    full_name='eolymp.community.Community.UpdateAttribute',
    index=10,
    containing_service=None,
    input_type=_UPDATEATTRIBUTEINPUT,
    output_type=_UPDATEATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\032%/community/attributes/{attribute_key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAttribute',
    full_name='eolymp.community.Community.RemoveAttribute',
    index=11,
    containing_service=None,
    input_type=_REMOVEATTRIBUTEINPUT,
    output_type=_REMOVEATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002**%/community/attributes/{attribute_key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeAttribute',
    full_name='eolymp.community.Community.DescribeAttribute',
    index=12,
    containing_service=None,
    input_type=_DESCRIBEATTRIBUTEINPUT,
    output_type=_DESCRIBEATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\022%/community/attributes/{attribute_key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAttributes',
    full_name='eolymp.community.Community.ListAttributes',
    index=13,
    containing_service=None,
    input_type=_LISTATTRIBUTESINPUT,
    output_type=_LISTATTRIBUTESOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\032\022\025/community/attributesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMUNITY)

DESCRIPTOR.services_by_name['Community'] = _COMMUNITY

# @@protoc_insertion_point(module_scope)
