# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/inline.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/typewriter/inline.proto',
  package='eolymp.typewriter',
  syntax='proto3',
  serialized_options=b'Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriter',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/typewriter/inline.proto\x12\x11\x65olymp.typewriter\"\xdc\x04\n\x06Inline\x12.\n\x04text\x18\x01 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.TextH\x00\x12.\n\x04link\x18\x02 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.LinkH\x00\x12.\n\x04math\x18\x03 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.MathH\x00\x12.\n\x04\x63ode\x18\x04 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.CodeH\x00\x12\x36\n\x08variable\x18\x05 \x01(\x0b\x32\".eolymp.typewriter.Inline.VariableH\x00\x1aO\n\x05Style\x12\x0c\n\x04\x62old\x18\x01 \x01(\x08\x12\x0e\n\x06italic\x18\x02 \x01(\x08\x12\x11\n\tunderline\x18\x03 \x01(\x08\x12\x15\n\rstrikethrough\x18\x04 \x01(\x08\x1a\x43\n\x04Text\x12\x0b\n\x03str\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.Style\x1a@\n\x04Link\x12\x0b\n\x03url\x18\x01 \x01(\t\x12+\n\x08\x63hildren\x18\n \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\x17\n\x04Math\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1a\x17\n\x04\x43ode\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1aH\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.StyleB\x06\n\x04nodeB=Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriterb\x06proto3'
)




_INLINE_STYLE = _descriptor.Descriptor(
  name='Style',
  full_name='eolymp.typewriter.Inline.Style',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bold', full_name='eolymp.typewriter.Inline.Style.bold', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='italic', full_name='eolymp.typewriter.Inline.Style.italic', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='underline', full_name='eolymp.typewriter.Inline.Style.underline', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strikethrough', full_name='eolymp.typewriter.Inline.Style.strikethrough', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=391,
)

_INLINE_TEXT = _descriptor.Descriptor(
  name='Text',
  full_name='eolymp.typewriter.Inline.Text',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='str', full_name='eolymp.typewriter.Inline.Text.str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='style', full_name='eolymp.typewriter.Inline.Text.style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=460,
)

_INLINE_LINK = _descriptor.Descriptor(
  name='Link',
  full_name='eolymp.typewriter.Inline.Link',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='eolymp.typewriter.Inline.Link.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='children', full_name='eolymp.typewriter.Inline.Link.children', index=1,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=526,
)

_INLINE_MATH = _descriptor.Descriptor(
  name='Math',
  full_name='eolymp.typewriter.Inline.Math',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='eolymp.typewriter.Inline.Math.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=551,
)

_INLINE_CODE = _descriptor.Descriptor(
  name='Code',
  full_name='eolymp.typewriter.Inline.Code',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='eolymp.typewriter.Inline.Code.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=576,
)

_INLINE_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='eolymp.typewriter.Inline.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.typewriter.Inline.Variable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='style', full_name='eolymp.typewriter.Inline.Variable.style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=650,
)

_INLINE = _descriptor.Descriptor(
  name='Inline',
  full_name='eolymp.typewriter.Inline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='eolymp.typewriter.Inline.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='eolymp.typewriter.Inline.link', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='math', full_name='eolymp.typewriter.Inline.math', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='eolymp.typewriter.Inline.code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='eolymp.typewriter.Inline.variable', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INLINE_STYLE, _INLINE_TEXT, _INLINE_LINK, _INLINE_MATH, _INLINE_CODE, _INLINE_VARIABLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node', full_name='eolymp.typewriter.Inline.node',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=54,
  serialized_end=658,
)

_INLINE_STYLE.containing_type = _INLINE
_INLINE_TEXT.fields_by_name['style'].message_type = _INLINE_STYLE
_INLINE_TEXT.containing_type = _INLINE
_INLINE_LINK.fields_by_name['children'].message_type = _INLINE
_INLINE_LINK.containing_type = _INLINE
_INLINE_MATH.containing_type = _INLINE
_INLINE_CODE.containing_type = _INLINE
_INLINE_VARIABLE.fields_by_name['style'].message_type = _INLINE_STYLE
_INLINE_VARIABLE.containing_type = _INLINE
_INLINE.fields_by_name['text'].message_type = _INLINE_TEXT
_INLINE.fields_by_name['link'].message_type = _INLINE_LINK
_INLINE.fields_by_name['math'].message_type = _INLINE_MATH
_INLINE.fields_by_name['code'].message_type = _INLINE_CODE
_INLINE.fields_by_name['variable'].message_type = _INLINE_VARIABLE
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['text'])
_INLINE.fields_by_name['text'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['link'])
_INLINE.fields_by_name['link'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['math'])
_INLINE.fields_by_name['math'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['code'])
_INLINE.fields_by_name['code'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['variable'])
_INLINE.fields_by_name['variable'].containing_oneof = _INLINE.oneofs_by_name['node']
DESCRIPTOR.message_types_by_name['Inline'] = _INLINE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Inline = _reflection.GeneratedProtocolMessageType('Inline', (_message.Message,), {

  'Style' : _reflection.GeneratedProtocolMessageType('Style', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_STYLE,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Style)
    })
  ,

  'Text' : _reflection.GeneratedProtocolMessageType('Text', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_TEXT,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Text)
    })
  ,

  'Link' : _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_LINK,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Link)
    })
  ,

  'Math' : _reflection.GeneratedProtocolMessageType('Math', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_MATH,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Math)
    })
  ,

  'Code' : _reflection.GeneratedProtocolMessageType('Code', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_CODE,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Code)
    })
  ,

  'Variable' : _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_VARIABLE,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Variable)
    })
  ,
  'DESCRIPTOR' : _INLINE,
  '__module__' : 'eolymp.typewriter.inline_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline)
  })
_sym_db.RegisterMessage(Inline)
_sym_db.RegisterMessage(Inline.Style)
_sym_db.RegisterMessage(Inline.Text)
_sym_db.RegisterMessage(Inline.Link)
_sym_db.RegisterMessage(Inline.Math)
_sym_db.RegisterMessage(Inline.Code)
_sym_db.RegisterMessage(Inline.Variable)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
