# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/helpdesk.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.helpdesk import document_pb2 as eolymp_dot_helpdesk_dot_document__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/helpdesk/helpdesk.proto',
  package='eolymp.helpdesk',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/helpdesk;helpdesk',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/helpdesk/helpdesk.proto\x12\x0f\x65olymp.helpdesk\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1d\x65olymp/annotations/http.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1e\x65olymp/helpdesk/document.proto\",\n\x15\x44\x65scribeDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeDocumentOutput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\xa0\x02\n\x12ListDocumentsInput\x12\x14\n\x0csearch_query\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.helpdesk.ListDocumentsInput.Filter\x1a\x98\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04path\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06locale\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"N\n\x13ListDocumentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document\"B\n\x13\x43reateDocumentInput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"+\n\x14\x43reateDocumentOutput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"W\n\x13UpdateDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\x12+\n\x08\x64ocument\x18\x02 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\x16\n\x14UpdateDocumentOutput\"*\n\x13\x44\x65leteDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteDocumentOutput\"<\n\x11\x44\x65scribePathInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\x02 \x03(\t\"A\n\x12\x44\x65scribePathOutput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\xfe\x01\n\x0eListPathsInput\x12\x19\n\x11preferred_locales\x18\x01 \x03(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.helpdesk.ListPathsInput.Filter\x1az\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12\x30\n\x04path\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x05label\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"J\n\x0fListPathsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document\";\n\x10ListParentsInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\x02 \x03(\t\"L\n\x11ListParentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document2\x8a\x0b\n\x08Helpdesk\x12\xc5\x01\n\x10\x44\x65scribeDocument\x12&.eolymp.helpdesk.DescribeDocumentInput\x1a\'.eolymp.helpdesk.DescribeDocumentOutput\"`\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02,\x12 /helpdesk/document/{document_id}:\x08\x64ocument\x12\xa2\x01\n\rListDocuments\x12#.eolymp.helpdesk.ListDocumentsInput\x1a$.eolymp.helpdesk.ListDocumentsOutput\"F\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x13\x12\x11/atlas/documents/\x12\xaa\x01\n\x0e\x43reateDocument\x12$.eolymp.helpdesk.CreateDocumentInput\x1a%.eolymp.helpdesk.CreateDocumentOutput\"K\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17\"\x12/helpdesk/document:\x01*\x12\xb8\x01\n\x0eUpdateDocument\x12$.eolymp.helpdesk.UpdateDocumentInput\x1a%.eolymp.helpdesk.UpdateDocumentOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02%\x1a /helpdesk/document/{document_id}:\x01*\x12\xb1\x01\n\x0e\x44\x65leteDocument\x12$.eolymp.helpdesk.DeleteDocumentInput\x1a%.eolymp.helpdesk.DeleteDocumentOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1e*\x19/helpdesk/document/{path}:\x01*\x12\xaf\x01\n\x0c\x44\x65scribePath\x12\".eolymp.helpdesk.DescribePathInput\x1a#.eolymp.helpdesk.DescribePathOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\"\x12\x16/helpdesk/paths/{path}:\x08\x64ocument\x12\x95\x01\n\tListPaths\x12\x1f.eolymp.helpdesk.ListPathsInput\x1a .eolymp.helpdesk.ListPathsOutput\"E\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x11\x12\x0f/helpdesk/paths\x12\xaa\x01\n\x0bListParents\x12!.eolymp.helpdesk.ListParentsInput\x1a\".eolymp.helpdesk.ListParentsOutput\"T\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02 \x12\x1e/helpdesk/paths/{path}/parentsB9Z7github.com/eolymp/contracts/go/eolymp/helpdesk;helpdeskb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_helpdesk_dot_document__pb2.DESCRIPTOR,])




_DESCRIBEDOCUMENTINPUT = _descriptor.Descriptor(
  name='DescribeDocumentInput',
  full_name='eolymp.helpdesk.DescribeDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.DescribeDocumentInput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=261,
)


_DESCRIBEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='DescribeDocumentOutput',
  full_name='eolymp.helpdesk.DescribeDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.DescribeDocumentOutput.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=332,
)


_LISTDOCUMENTSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.helpdesk.ListDocumentsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.helpdesk.ListDocumentsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.ListDocumentsInput.Filter.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.helpdesk.ListDocumentsInput.Filter.locale', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=623,
)

_LISTDOCUMENTSINPUT = _descriptor.Descriptor(
  name='ListDocumentsInput',
  full_name='eolymp.helpdesk.ListDocumentsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_query', full_name='eolymp.helpdesk.ListDocumentsInput.search_query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.helpdesk.ListDocumentsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.helpdesk.ListDocumentsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.helpdesk.ListDocumentsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDOCUMENTSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=623,
)


_LISTDOCUMENTSOUTPUT = _descriptor.Descriptor(
  name='ListDocumentsOutput',
  full_name='eolymp.helpdesk.ListDocumentsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.helpdesk.ListDocumentsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.helpdesk.ListDocumentsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=703,
)


_CREATEDOCUMENTINPUT = _descriptor.Descriptor(
  name='CreateDocumentInput',
  full_name='eolymp.helpdesk.CreateDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.CreateDocumentInput.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=771,
)


_CREATEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='CreateDocumentOutput',
  full_name='eolymp.helpdesk.CreateDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.CreateDocumentOutput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=816,
)


_UPDATEDOCUMENTINPUT = _descriptor.Descriptor(
  name='UpdateDocumentInput',
  full_name='eolymp.helpdesk.UpdateDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.UpdateDocumentInput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.UpdateDocumentInput.document', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=905,
)


_UPDATEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='UpdateDocumentOutput',
  full_name='eolymp.helpdesk.UpdateDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=929,
)


_DELETEDOCUMENTINPUT = _descriptor.Descriptor(
  name='DeleteDocumentInput',
  full_name='eolymp.helpdesk.DeleteDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.DeleteDocumentInput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=973,
)


_DELETEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='DeleteDocumentOutput',
  full_name='eolymp.helpdesk.DeleteDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=997,
)


_DESCRIBEPATHINPUT = _descriptor.Descriptor(
  name='DescribePathInput',
  full_name='eolymp.helpdesk.DescribePathInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.DescribePathInput.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.helpdesk.DescribePathInput.preferred_locales', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=999,
  serialized_end=1059,
)


_DESCRIBEPATHOUTPUT = _descriptor.Descriptor(
  name='DescribePathOutput',
  full_name='eolymp.helpdesk.DescribePathOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.DescribePathOutput.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1061,
  serialized_end=1126,
)


_LISTPATHSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.helpdesk.ListPathsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='eolymp.helpdesk.ListPathsInput.Filter.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.ListPathsInput.Filter.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='eolymp.helpdesk.ListPathsInput.Filter.label', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1383,
)

_LISTPATHSINPUT = _descriptor.Descriptor(
  name='ListPathsInput',
  full_name='eolymp.helpdesk.ListPathsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.helpdesk.ListPathsInput.preferred_locales', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.helpdesk.ListPathsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.helpdesk.ListPathsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.helpdesk.ListPathsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPATHSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1383,
)


_LISTPATHSOUTPUT = _descriptor.Descriptor(
  name='ListPathsOutput',
  full_name='eolymp.helpdesk.ListPathsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.helpdesk.ListPathsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.helpdesk.ListPathsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=1459,
)


_LISTPARENTSINPUT = _descriptor.Descriptor(
  name='ListParentsInput',
  full_name='eolymp.helpdesk.ListParentsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.ListParentsInput.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.helpdesk.ListParentsInput.preferred_locales', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1461,
  serialized_end=1520,
)


_LISTPARENTSOUTPUT = _descriptor.Descriptor(
  name='ListParentsOutput',
  full_name='eolymp.helpdesk.ListParentsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.helpdesk.ListParentsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.helpdesk.ListParentsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1522,
  serialized_end=1598,
)

_DESCRIBEDOCUMENTOUTPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_LISTDOCUMENTSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTDOCUMENTSINPUT_FILTER.fields_by_name['path'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTDOCUMENTSINPUT_FILTER.fields_by_name['locale'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTDOCUMENTSINPUT_FILTER.containing_type = _LISTDOCUMENTSINPUT
_LISTDOCUMENTSINPUT.fields_by_name['filters'].message_type = _LISTDOCUMENTSINPUT_FILTER
_LISTDOCUMENTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_CREATEDOCUMENTINPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_UPDATEDOCUMENTINPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_DESCRIBEPATHOUTPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_LISTPATHSINPUT_FILTER.fields_by_name['path'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTPATHSINPUT_FILTER.fields_by_name['label'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTPATHSINPUT_FILTER.containing_type = _LISTPATHSINPUT
_LISTPATHSINPUT.fields_by_name['filters'].message_type = _LISTPATHSINPUT_FILTER
_LISTPATHSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_LISTPARENTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
DESCRIPTOR.message_types_by_name['DescribeDocumentInput'] = _DESCRIBEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['DescribeDocumentOutput'] = _DESCRIBEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['ListDocumentsInput'] = _LISTDOCUMENTSINPUT
DESCRIPTOR.message_types_by_name['ListDocumentsOutput'] = _LISTDOCUMENTSOUTPUT
DESCRIPTOR.message_types_by_name['CreateDocumentInput'] = _CREATEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['CreateDocumentOutput'] = _CREATEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateDocumentInput'] = _UPDATEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['UpdateDocumentOutput'] = _UPDATEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteDocumentInput'] = _DELETEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['DeleteDocumentOutput'] = _DELETEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['DescribePathInput'] = _DESCRIBEPATHINPUT
DESCRIPTOR.message_types_by_name['DescribePathOutput'] = _DESCRIBEPATHOUTPUT
DESCRIPTOR.message_types_by_name['ListPathsInput'] = _LISTPATHSINPUT
DESCRIPTOR.message_types_by_name['ListPathsOutput'] = _LISTPATHSOUTPUT
DESCRIPTOR.message_types_by_name['ListParentsInput'] = _LISTPARENTSINPUT
DESCRIPTOR.message_types_by_name['ListParentsOutput'] = _LISTPARENTSOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DescribeDocumentInput = _reflection.GeneratedProtocolMessageType('DescribeDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribeDocumentInput)
  })
_sym_db.RegisterMessage(DescribeDocumentInput)

DescribeDocumentOutput = _reflection.GeneratedProtocolMessageType('DescribeDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribeDocumentOutput)
  })
_sym_db.RegisterMessage(DescribeDocumentOutput)

ListDocumentsInput = _reflection.GeneratedProtocolMessageType('ListDocumentsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTDOCUMENTSINPUT_FILTER,
    '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListDocumentsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTDOCUMENTSINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListDocumentsInput)
  })
_sym_db.RegisterMessage(ListDocumentsInput)
_sym_db.RegisterMessage(ListDocumentsInput.Filter)

ListDocumentsOutput = _reflection.GeneratedProtocolMessageType('ListDocumentsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTDOCUMENTSOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListDocumentsOutput)
  })
_sym_db.RegisterMessage(ListDocumentsOutput)

CreateDocumentInput = _reflection.GeneratedProtocolMessageType('CreateDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.CreateDocumentInput)
  })
_sym_db.RegisterMessage(CreateDocumentInput)

CreateDocumentOutput = _reflection.GeneratedProtocolMessageType('CreateDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.CreateDocumentOutput)
  })
_sym_db.RegisterMessage(CreateDocumentOutput)

UpdateDocumentInput = _reflection.GeneratedProtocolMessageType('UpdateDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.UpdateDocumentInput)
  })
_sym_db.RegisterMessage(UpdateDocumentInput)

UpdateDocumentOutput = _reflection.GeneratedProtocolMessageType('UpdateDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.UpdateDocumentOutput)
  })
_sym_db.RegisterMessage(UpdateDocumentOutput)

DeleteDocumentInput = _reflection.GeneratedProtocolMessageType('DeleteDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DeleteDocumentInput)
  })
_sym_db.RegisterMessage(DeleteDocumentInput)

DeleteDocumentOutput = _reflection.GeneratedProtocolMessageType('DeleteDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DeleteDocumentOutput)
  })
_sym_db.RegisterMessage(DeleteDocumentOutput)

DescribePathInput = _reflection.GeneratedProtocolMessageType('DescribePathInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPATHINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribePathInput)
  })
_sym_db.RegisterMessage(DescribePathInput)

DescribePathOutput = _reflection.GeneratedProtocolMessageType('DescribePathOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPATHOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribePathOutput)
  })
_sym_db.RegisterMessage(DescribePathOutput)

ListPathsInput = _reflection.GeneratedProtocolMessageType('ListPathsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTPATHSINPUT_FILTER,
    '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListPathsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTPATHSINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListPathsInput)
  })
_sym_db.RegisterMessage(ListPathsInput)
_sym_db.RegisterMessage(ListPathsInput.Filter)

ListPathsOutput = _reflection.GeneratedProtocolMessageType('ListPathsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPATHSOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListPathsOutput)
  })
_sym_db.RegisterMessage(ListPathsOutput)

ListParentsInput = _reflection.GeneratedProtocolMessageType('ListParentsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARENTSINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListParentsInput)
  })
_sym_db.RegisterMessage(ListParentsInput)

ListParentsOutput = _reflection.GeneratedProtocolMessageType('ListParentsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARENTSOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListParentsOutput)
  })
_sym_db.RegisterMessage(ListParentsOutput)


DESCRIPTOR._options = None

_HELPDESK = _descriptor.ServiceDescriptor(
  name='Helpdesk',
  full_name='eolymp.helpdesk.Helpdesk',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1601,
  serialized_end=3019,
  methods=[
  _descriptor.MethodDescriptor(
    name='DescribeDocument',
    full_name='eolymp.helpdesk.Helpdesk.DescribeDocument',
    index=0,
    containing_service=None,
    input_type=_DESCRIBEDOCUMENTINPUT,
    output_type=_DESCRIBEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002,\022 /helpdesk/document/{document_id}:\010document',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDocuments',
    full_name='eolymp.helpdesk.Helpdesk.ListDocuments',
    index=1,
    containing_service=None,
    input_type=_LISTDOCUMENTSINPUT,
    output_type=_LISTDOCUMENTSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\023\022\021/atlas/documents/',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDocument',
    full_name='eolymp.helpdesk.Helpdesk.CreateDocument',
    index=2,
    containing_service=None,
    input_type=_CREATEDOCUMENTINPUT,
    output_type=_CREATEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027\"\022/helpdesk/document:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDocument',
    full_name='eolymp.helpdesk.Helpdesk.UpdateDocument',
    index=3,
    containing_service=None,
    input_type=_UPDATEDOCUMENTINPUT,
    output_type=_UPDATEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002%\032 /helpdesk/document/{document_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDocument',
    full_name='eolymp.helpdesk.Helpdesk.DeleteDocument',
    index=4,
    containing_service=None,
    input_type=_DELETEDOCUMENTINPUT,
    output_type=_DELETEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\036*\031/helpdesk/document/{path}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribePath',
    full_name='eolymp.helpdesk.Helpdesk.DescribePath',
    index=5,
    containing_service=None,
    input_type=_DESCRIBEPATHINPUT,
    output_type=_DESCRIBEPATHOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\"\022\026/helpdesk/paths/{path}:\010document',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPaths',
    full_name='eolymp.helpdesk.Helpdesk.ListPaths',
    index=6,
    containing_service=None,
    input_type=_LISTPATHSINPUT,
    output_type=_LISTPATHSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\021\022\017/helpdesk/paths',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListParents',
    full_name='eolymp.helpdesk.Helpdesk.ListParents',
    index=7,
    containing_service=None,
    input_type=_LISTPARENTSINPUT,
    output_type=_LISTPARENTSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002 \022\036/helpdesk/paths/{path}/parents',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HELPDESK)

DESCRIPTOR.services_by_name['Helpdesk'] = _HELPDESK

# @@protoc_insertion_point(module_scope)
