# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/attribute.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/community/attribute.proto',
  package='eolymp.community',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/community;community',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/community/attribute.proto\x12\x10\x65olymp.community\"\xb6\x03\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x0b\x64\x65scription\x18\n \x03(\x0b\x32\'.eolymp.community.Attribute.Description\x12.\n\x04type\x18\x14 \x01(\x0e\x32 .eolymp.community.Attribute.Type\x12\r\n\x05index\x18\x15 \x01(\r\x12\x10\n\x08required\x18\x1f \x01(\x08\x12\x0e\n\x06hidden\x18  \x01(\x08\x12\x0e\n\x06regexp\x18\x64 \x01(\t\x12\x0b\n\x03min\x18\x65 \x01(\x05\x12\x0b\n\x03max\x18\x66 \x01(\x05\x12\x0f\n\x07\x63hoices\x18g \x03(\t\x1a\\\n\x0b\x44\x65scription\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\"d\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x08\n\x04TEXT\x10\x02\x12\n\n\x06NUMBER\x10\x03\x12\n\n\x06\x43HOICE\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\t\n\x05\x45MAIL\x10\x06\x12\x0c\n\x08\x43HECKBOX\x10\x07\x42;Z9github.com/eolymp/contracts/go/eolymp/community;communityb\x06proto3'
)



_ATTRIBUTE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.community.Attribute.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHOICE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECKBOX', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=393,
  serialized_end=493,
)
_sym_db.RegisterEnumDescriptor(_ATTRIBUTE_TYPE)


_ATTRIBUTE_DESCRIPTION = _descriptor.Descriptor(
  name='Description',
  full_name='eolymp.community.Attribute.Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default', full_name='eolymp.community.Attribute.Description.default', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.community.Attribute.Description.locale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='eolymp.community.Attribute.Description.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='help', full_name='eolymp.community.Attribute.Description.help', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.community.Attribute.Description.choices', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=391,
)

_ATTRIBUTE = _descriptor.Descriptor(
  name='Attribute',
  full_name='eolymp.community.Attribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.community.Attribute.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='eolymp.community.Attribute.description', index=1,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.community.Attribute.type', index=2,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.community.Attribute.index', index=3,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='eolymp.community.Attribute.required', index=4,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='eolymp.community.Attribute.hidden', index=5,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regexp', full_name='eolymp.community.Attribute.regexp', index=6,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='eolymp.community.Attribute.min', index=7,
      number=101, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='eolymp.community.Attribute.max', index=8,
      number=102, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.community.Attribute.choices', index=9,
      number=103, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTE_DESCRIPTION, ],
  enum_types=[
    _ATTRIBUTE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=493,
)

_ATTRIBUTE_DESCRIPTION.containing_type = _ATTRIBUTE
_ATTRIBUTE.fields_by_name['description'].message_type = _ATTRIBUTE_DESCRIPTION
_ATTRIBUTE.fields_by_name['type'].enum_type = _ATTRIBUTE_TYPE
_ATTRIBUTE_TYPE.containing_type = _ATTRIBUTE
DESCRIPTOR.message_types_by_name['Attribute'] = _ATTRIBUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Attribute = _reflection.GeneratedProtocolMessageType('Attribute', (_message.Message,), {

  'Description' : _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
    'DESCRIPTOR' : _ATTRIBUTE_DESCRIPTION,
    '__module__' : 'eolymp.community.attribute_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.community.Attribute.Description)
    })
  ,
  'DESCRIPTOR' : _ATTRIBUTE,
  '__module__' : 'eolymp.community.attribute_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.Attribute)
  })
_sym_db.RegisterMessage(Attribute)
_sym_db.RegisterMessage(Attribute.Description)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
